@@ -64,8 +64,9 @@ public:
   type_signal_requested_related_details signal_requested_related_details();
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual void show_layout_toolbar (bool show = true);
+  void show_layout_toolbar(bool show = true);
 #endif
+
 protected:
 
 
