@@ -25,14 +25,17 @@ namespace Glom
 {
 
 Box_Data_List_Find::Box_Data_List_Find()
-: m_HBox(false, 6)
+: m_HBox(false, Glom::Utils::DEFAULT_SPACING_SMALL)
 {
   //m_strHint = _("Enter the search criteria and click [Find]\n Glom will then change to Data mode to display the results.");
 
   m_HBox.pack_end(m_Button_Find, Gtk::PACK_SHRINK);
   pack_start(m_HBox, Gtk::PACK_SHRINK);
 
-  m_Button_Find.property_can_default() = true; //TODO: Make this a real method in gtkmm?
+  g_object_set(m_Button_Find.gobj(), "can-default", TRUE, (gpointer)NULL); //TODO: Make this a real method in gtkmm?
+
+  //Prevent the widget from trying to add or change records:
+  m_AddDel.set_find_mode();
 
   show_all_children();
 }
@@ -50,7 +53,7 @@ bool Box_Data_List_Find::fill_from_database()
 {
   Bakery::BusyCursor busy_cursor(get_app_window());
 
-  const bool result = Box_DB_Table::fill_from_database();
+  const bool result = Base_DB_Table_Data::fill_from_database();
   if(!result)
     return false;
 
@@ -64,27 +67,12 @@ bool Box_Data_List_Find::fill_from_database()
   return result;
 }
 
-void Box_Data_List_Find::on_adddel_user_changed(const Gtk::TreeModel::iterator& /* row */, guint /* col */)
-{
-  //Just block the implementation in the base class.
-}
-
 
 Gtk::Widget* Box_Data_List_Find::get_default_button() //override
 {
   return &m_Button_Find;
 }
 
-void Box_Data_List_Find::on_adddel_user_requested_delete(const Gtk::TreeModel::iterator& /* rowStart */, const Gtk::TreeModel::iterator&  /* rowEnd TODO */)
-{
-  //Ignore this, instead of updating the database, as the base class does.
-}
-
-void Box_Data_List_Find::on_adddel_user_added(const Gtk::TreeModel::iterator& /* row */, guint /* col_with_first_value */)
-{
-  //Ignore this, instead of updating the database, as the base class does.
-}
-
 bool Box_Data_List_Find::init_db_details(const Glib::ustring& table_name)
 {
   FoundSet found_set;
